# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['nevax']

package_data = \
{'': ['*']}

install_requires = \
['einops', 'torch', 'transformers']

setup_kwargs = {
    'name': 'nevax',
    'version': '0.1.2',
    'description': "NeVA: NVIDIA's Visual Question Answering Transformer",
    'long_description': "# NeVA: NVIDIA's Visual Question Answering Transformer\n\nNeVA is a powerful and versatile Visual Question Answering model powered by NVIDIA's expertise. It builds upon the open-source LLaMA model, integrating it with an NVIDIA-trained GPT model to offer state-of-the-art performance.\n\n---\n\n## Installation\n\nTo integrate NeVA into your Python environment, you can install it via pip:\n\n```bash\npip install nevax\n```\n---\n\n## Usage\n\n```python\nimport torch\nfrom nevax.model import Neva\n\n#usage\nimg = torch.randn(1, 3, 256, 256)\ncaption_tokens = torch.randint(0, 4)\n\nmodel = Neva()\noutput = model(img, caption_tokens)\n```\n\n## Description\n\nAt a high level, NeVA utilizes a frozen Hugging Face CLIP model to encode images. These encoded images are projected to text embedding dimensions, concatenated with the embeddings of the given prompt, and subsequently passed through the language model. The training process comprises two main stages:\n\n1. **Pretraining**: Only the projection layer is trained with the language model kept frozen. This stage uses image-caption pairs for training.\n2. **Finetuning**: Both the language model and the projection layer are trained. This stage utilizes synthetic instruction data generated with GPT4.\n\n## Model Specifications\n\n- **Architecture Type**: Transformer\n- **Network Architecture**: GPT + CLIP\n- **Model versions**: 8B, 22B, 43B\n\n## Input & Output\n\n- **Input Format**: RGB Image + Text\n- **Input Parameters**: temperature, max output tokens, quality, toxicity, humor, creativity, violence, helpfulness, not_appropriate\n- **Output Format**: Text\n\n## Integration and Compatibility\n\n- **Supported Hardware Platforms**: Hopper, Ampere/Turing\n- **Supported Operating Systems**: Linux\n- **Runtime**: N/A\n\n## Training & Fine-tuning Data\n\n**Pretraining Dataset**:\n- **Link**: [CC-3M](#)\n- **Description**: The dataset comprises CC3M images and captions, refined to 595,000 samples.\n- **License**: [COCO](#), [CC-3M](#), [BLIP](#)\n\n**Finetuning Dataset**:\n- **Link**: Synthetic data produced by GPT4\n- **Description**: The dataset, with 158,000 samples, was synthetically generated by GPT4. It encompasses a blend of short question answers, detailed image descriptions, and higher-level reasoning questions.\n- **License**: [CC-BY-NC 4.0 License](https://creativecommons.org/licenses/by-nc/4.0/)\n\n## Inference\n\n- **Engine**: Triton\n- **Test Hardware**: Other\n\n## References\n\n- [Visual Instruction Tuning paper](#)\n- [Blog](#)\n- [Codebase](#)\n- [Demo](#)\n\n## Licensing\n\nThis project is licensed under the [MIT License](/LICENSE) license.\n\n\n# Citation",
    'author': 'Kye Gomez',
    'author_email': 'kye@apac.ai',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/kyegomez/neva',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
